"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileTypes = exports.FILE_TYPES_REQUIRED_ADDITIONAL_CHECK = void 0;
const utils_1 = require("../../utils");
const audio_1 = require("./audio");
const compressed_1 = require("./compressed");
const other_1 = require("./other");
const image_1 = require("./image");
const video_1 = require("./video");
const validation_1 = require("../../validation");
exports.FILE_TYPES_REQUIRED_ADDITIONAL_CHECK = [
    "m4v",
    "flv",
    "mp4",
    "mkv",
    "webm",
    "avif",
    "heic",
];
/**
 * A class hold all supported file typs with their unique signatures
 */
class FileTypes {
    /**
     * Receive information on a file type by its property name from FileTypes class
     *
     * @param propertyName Property name from FileTypes class
     *
     * @returns {FileInfo} File type information
     */
    static getInfoByName(propertyName) {
        const file = (0, utils_1.fetchFromObject)(FileTypes, propertyName.toUpperCase());
        return file;
    }
    /**
     * Receive an array of file type signatures by its property name from FileTypes class
     *
     * @param propertyName Property name from FileTypes class
     *
     * @returns {Array<FileSignature>} All unique signatures with their information
     */
    static getSignaturesByName(propertyName) {
        const { signatures } = (0, utils_1.fetchFromObject)(FileTypes, propertyName.toUpperCase());
        return signatures;
    }
    /**
     * Determine if a valid signature exist in a file chunk
     *
     * @param fileChunk A chunk from the beginning of a file content, represents in array of numbers
     * @param acceptedSignatures Valid signatures to search for in fileChunk
     *
     * @returns {boolean} True if found a valid signature inside the chunk, otherwise false
     */
    static detectSignature(fileChunk, acceptedSignatures) {
        for (const signature of acceptedSignatures) {
            let found = true;
            const offset = signature.offset || 0;
            let skippedBytes = 0;
            for (let i = 0; i < signature.sequence.length; i++) {
                if (signature.skippedBytes && signature.skippedBytes.includes(i)) {
                    skippedBytes++;
                    continue;
                }
                if (fileChunk[offset + i] !== signature.sequence[i - skippedBytes]) {
                    found = false;
                    break;
                }
            }
            if (found) {
                return signature;
            }
        }
        return undefined;
    }
    /**
     * Perfomrs an additional check for detected file types by their unique structure
     *
     * @param fileChunk A chunk from the beginning of a file content, represents in array of numbers
     * @param detectedFiles A list of detected files
     * @returns {string | undefined} File type extension if found, otherwise undefined
     */
    static detectTypeByAdditionalCheck(fileChunk, detectedFiles) {
        const detectedExtensions = detectedFiles.map((df) => df.extension);
        if (detectedExtensions.some((de) => ["m4v", "flv", "mp4", "heic"].includes(de))) {
            if (detectedExtensions.includes("heic") && (0, validation_1.isHEIC)(fileChunk))
                return "heic";
            const isFlv = (0, validation_1.isFLV)(fileChunk);
            if (isFlv)
                return "flv";
            const isM4v = (0, validation_1.isM4V)(fileChunk) && !(0, validation_1.isHEIC)(fileChunk);
            if (isM4v)
                return "m4v";
            return "mp4";
        }
        else if (detectedExtensions.some((de) => ["mkv", "webm"].includes(de))) {
            const matroskaDocTypeElement = (0, utils_1.findMatroskaDocTypeElements)(fileChunk);
            if (matroskaDocTypeElement === "mkv" && (0, validation_1.isMKV)(fileChunk))
                return "mkv";
            else if (matroskaDocTypeElement === "webm" && (0, validation_1.isWEBM)(fileChunk))
                return "webm";
            return undefined;
        }
        else if (detectedExtensions.some((de) => ["avif"].includes(de))) {
            const isAvif = (0, utils_1.isAvifStringIncluded)(fileChunk);
            if (isAvif)
                return "avif";
        }
        return undefined;
    }
    /**
     * Determine if a file chunk contains a valid signature and return the file signature if exist
     *
     * @param fileChunk A chunk from the beginning of a file content, represents in array of numbers
     * @param acceptedSignatures Valid signatures to search for in fileChunk
     *
     * @returns {FileSignature | undefined } FileSignature if found a valid signature, otherwise undefined
     */
    static detectbBySignatures(fileChunk, acceptedSignatures) {
        for (const signature of acceptedSignatures) {
            let skippedBytes = 0;
            let found = true;
            const offset = signature.offset || 0;
            const signatureLength = (signature === null || signature === void 0 ? void 0 : signature.skippedBytes)
                ? signature.sequence.length + signature.skippedBytes.length
                : signature.sequence.length;
            for (let i = 0; i < signatureLength; i++) {
                if (signature.skippedBytes && signature.skippedBytes.includes(i)) {
                    skippedBytes++;
                    continue;
                }
                if (fileChunk[offset + i] !== signature.sequence[i - skippedBytes]) {
                    found = false;
                    break;
                }
            }
            if (found) {
                return signature;
            }
        }
        return undefined;
    }
    /**
     * Determine if file content contains a valid signature of a required type
     *
     * @param fileChunk A chunk from the beginning of a file content, represents in array of numbers
     * @param type The file type to match against
     *
     * @returns {boolean} True if found a signature of the type in file content, otherwise false
     */
    static checkByFileType(fileChunk, type) {
        if (Object.prototype.hasOwnProperty.call(FileTypes, type.toUpperCase())) {
            const acceptedSignatures = FileTypes.getSignaturesByName(type.toUpperCase());
            const detectedSignature = FileTypes.detectSignature(fileChunk, acceptedSignatures);
            if (detectedSignature)
                return true;
        }
        return false;
    }
}
exports.FileTypes = FileTypes;
// audio
FileTypes.AAC = audio_1.AudioTypes.AAC;
FileTypes.AMR = audio_1.AudioTypes.AMR;
FileTypes.FLAC = audio_1.AudioTypes.FLAC;
FileTypes.M4A = audio_1.AudioTypes.M4A;
FileTypes.MP3 = audio_1.AudioTypes.MP3;
FileTypes.WAV = audio_1.AudioTypes.WAV;
// image
FileTypes.AVIF = image_1.ImageTypes.AVIF;
FileTypes.BMP = image_1.ImageTypes.BMP;
FileTypes.BPG = image_1.ImageTypes.BPG;
FileTypes.CR2 = image_1.ImageTypes.CR2;
FileTypes.EXR = image_1.ImageTypes.EXR;
FileTypes.GIF = image_1.ImageTypes.GIF;
FileTypes.ICO = image_1.ImageTypes.ICO;
FileTypes.JPEG = image_1.ImageTypes.JPEG;
FileTypes.PBM = image_1.ImageTypes.PBM;
FileTypes.PGM = image_1.ImageTypes.PGM;
FileTypes.PNG = image_1.ImageTypes.PNG;
FileTypes.PPM = image_1.ImageTypes.PPM;
FileTypes.PSD = image_1.ImageTypes.PSD;
FileTypes.WEBP = image_1.ImageTypes.WEBP;
FileTypes.HEIC = image_1.ImageTypes.HEIC;
// video
FileTypes.AVI = video_1.VideoTypes.AVI;
FileTypes.FLV = video_1.VideoTypes.FLV;
FileTypes.M4V = video_1.VideoTypes.M4V;
FileTypes.MKV = video_1.VideoTypes.MKV;
FileTypes.MOV = video_1.VideoTypes.MOV;
FileTypes.MP4 = video_1.VideoTypes.MP4;
FileTypes.OGG = video_1.VideoTypes.OGG;
FileTypes.SWF = video_1.VideoTypes.SWF;
FileTypes.WEBM = video_1.VideoTypes.WEBM;
// compressed
FileTypes._7Z = compressed_1.CompressedTypes._7Z;
FileTypes.LZH = compressed_1.CompressedTypes.LZH;
FileTypes.RAR = compressed_1.CompressedTypes.RAR;
FileTypes.ZIP = compressed_1.CompressedTypes.ZIP;
// other
FileTypes.BLEND = other_1.OtherTypes.BLEND;
FileTypes.DOC = other_1.OtherTypes.DOC;
FileTypes.ELF = other_1.OtherTypes.ELF;
FileTypes.EXE = other_1.OtherTypes.EXE;
FileTypes.INDD = other_1.OtherTypes.INDD;
FileTypes.MACHO = other_1.OtherTypes.MACHO;
FileTypes.ORC = other_1.OtherTypes.ORC;
FileTypes.PARQUET = other_1.OtherTypes.PARQUET;
FileTypes.PCAP = other_1.OtherTypes.PCAP;
FileTypes.PDF = other_1.OtherTypes.PDF;
FileTypes.PS = other_1.OtherTypes.PS;
FileTypes.RTF = other_1.OtherTypes.RTF;
FileTypes.SQLITE = other_1.OtherTypes.SQLITE;
FileTypes.STL = other_1.OtherTypes.STL;
FileTypes.TTF = other_1.OtherTypes.TTF;
